@@ -1,7 +1,6 @@
 function hasInherit(property) {
   for (var i = property.value.length - 1; i >= 0; i--) {
-    if (property.value[i][1] == 'inherit')
-      return true;
+    if (property.value[i][1] == 'inherit') { return true; }
   }
 
   return false;
